@@ -2,6 +2,7 @@ import json
 from rich import print
 
 import girok.utils.general as general_utils
+import girok.utils.display as display_utils
 import girok.api.auth as auth_api
 
 def match_passwords(pwd, confirm_pwd):
@@ -10,12 +11,20 @@ def match_passwords(pwd, confirm_pwd):
         exit(0)
         
 
+def get_mode(config_path):
+    with open(config_path, "r") as f:
+        cfg = json.load(f)
+        if "mode" not in cfg:
+            return None
+        return cfg['mode']
+            
+        
 def remove_access_token(config_path):
     with open(config_path, 'r') as f:
         org_data = json.load(f)
         del org_data['access_token']
-        del org_data['email']
-        
+        org_data['mode'] = "off"
+
     general_utils.write_json(config_path, org_data)
         
         
@@ -27,7 +36,6 @@ def get_access_token_from_json(fpath):
         else:
             return None
         
-
 def get_user_email_from_json(fpath):
     with open(fpath, 'r') as f:
         data = json.load(f)
@@ -48,6 +56,32 @@ def is_logged_in(access_token):
         return False
     resp = auth_api.validate_access_token(access_token)
     return True if resp.status_code == 200 else False
+
+
+def log_out_from_guest(cfg_path: str):
+    general_utils.update_json(cfg_path, {"mode": "off"})
+    
+
+def log_out_from_user(cfg_path: str):
+    with open(cfg_path, 'r') as f:
+        org_data = json.load(f)
+        del org_data['access_token']
+        org_data['mode'] = "off"
+
+    general_utils.write_json(cfg_path, org_data)
+
+
+def is_logged_in_as_guest(cfg_path: str):
+    mode = get_mode(cfg_path)
+    return True if mode == "guest" else False
+
+
+def is_logged_in_as_user(cfg_path: str):
+    access_token = get_access_token_from_json(cfg_path)
+    if access_token is None:
+        return False
+    resp = auth_api.validate_access_token(access_token)
+    return True if resp.status_code == 200 else False
         
 
 def store_access_token_to_json(fpath, access_token):
